@@ -5,6 +5,6 @@
   # Sys.setlocale(locale = "UTF-8")
   # Sys.setlocale(locale = "WINDOWS-1252")
 
-  packageStartupMessage("sweidnumbr: R tools to handle swedish identity numbers.\nhttps://github.com/rOpenGov/sweidnumbr\n\n")
+  packageStartupMessage("sweidnumbr: R tools to handle swedish identity numbers.\nhttps://github.com/rOpenGov/sweidnumbr\n")
 
 }
