@@ -15,9 +15,6 @@ test_that(desc="error expected",{
 })
 
 
-
-
-
 test_oins <- c("556000-4615", "232100-0156", "802002-4280")
 test_that("Recycling rules", {
   expect_is(data.frame(as.oin(test_oins), 1:9), "data.frame")
@@ -26,3 +23,9 @@ test_that("Recycling rules", {
   expect_equal(data.frame(as.oin(test_oins), 1:9)[1:3, 1], data.frame(as.oin(test_oins), 1:9)[7:9, 1])
 })
 
+
+test_that("Same error messages as in as.pin() is used", {
+  num_to_check <- c("202100-6255","121212-1212","19121212-1212","121212+1212", 1212121212, NA, Inf, TRUE, F, "foo", 123, 456L)
+  expect_warning(as.oin(num_to_check), "Erroneous oin\\(s\\) \\(set to NA\\)\\.")
+})
+
